@@ -2,7 +2,8 @@ from django.conf.urls import patterns, url
 
 
 def newsletter_subscriptions_urlpatterns(**kwargs):
-    return patterns('newsletter_subscription.views',
+    return patterns(
+        'newsletter_subscription.views',
         url(r'^$', 'form', kwargs,
             name='newsletter_subscription_form',
             ),
